@@ -126,14 +126,16 @@ def list_cached(args):
         if last_accessed == 0:
             last_accessed = "N/A"
         else:
-            last_accessed = datetime.datetime.utcfromtimestamp(
-                last_accessed).isoformat()
+            last_accessed = datetime.datetime.fromtimestamp(
+                last_accessed, tz=datetime.timezone.utc).replace(
+                    tzinfo=None).isoformat()
 
         pretty_table.add_row((
             image['image_id'],
             last_accessed,
-            datetime.datetime.utcfromtimestamp(
-                image['last_modified']).isoformat(),
+            datetime.datetime.fromtimestamp(
+                image['last_modified'], tz=datetime.timezone.utc).replace(
+                    tzinfo=None).isoformat(),
             image['size'],
             image['hits']))
 
@@ -499,6 +501,9 @@ def user_confirm(prompt, default=False):
 
 
 def main():
+    print('In the Caracal development cycle, the glance-cache-manage command '
+          'has been deprecated in favor of the new Cache API. It is scheduled '
+          'to be removed in the Dalmatian development cycle.', file=sys.stderr)
     parser = argparse.ArgumentParser(
         description=_format_command_help(),
         formatter_class=argparse.RawDescriptionHelpFormatter)
